@@ -29,7 +29,7 @@ impl TheWay {
         let start_index = self.get_current_snippet_index()? + 1;
         let snippets = Snippet::from_gist(start_index, &self.languages, &gist);
         for snippet in &snippets {
-            self.add_snippet(&snippet)?;
+            self.add_snippet(snippet)?;
             self.increment_snippet_index()?;
         }
         Ok(snippets)
